# RecordV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**orcid_identifier** | [**OrcidIdentifierV30Rc2**](OrcidIdentifierV30Rc2.md) |  | [optional] 
**preferences** | [**PreferencesV30Rc2**](PreferencesV30Rc2.md) |  | [optional] 
**history** | [**HistoryV30Rc2**](HistoryV30Rc2.md) |  | [optional] 
**person** | [**PersonV30Rc2**](PersonV30Rc2.md) |  | [optional] 
**activities_summary** | [**ActivitiesSummaryV30Rc2**](ActivitiesSummaryV30Rc2.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

